package cn.hnthyy.thmz.service.his.zd;

import cn.hnthyy.thmz.entity.his.zd.ZdChargeItem;
import cn.hnthyy.thmz.pageDto.ZdChargeItemDto;

import java.util.List;

public interface ZdChargeItemService {

    /**
     * 分页查询收费项目字典列表
     *
     * @param zdChargeItemDto 收费项目查询条件
     * @return
     */
    List<ZdChargeItem> queryZdChargeItemWithPage(ZdChargeItemDto zdChargeItemDto);


    /**
     * 统计收费项目字典
     *
     * @param zdChargeItem 收费项目查询条件
     * @return
     */
    int countZdChargeItem(ZdChargeItem zdChargeItem);


    /**
     * 根据单个收费项目编码查询字典
     *
     * @param code
     * @return
     */
    ZdChargeItem queryZdChargeItemByCode(String code);

    /**
     * 根据收费项目编码集合查询所包含的收费项目
     * @param codes
     * @return
     */
    List<ZdChargeItem> queryZdChargeItemByCodeList(List<String> codes);


    /**
     * 查询所有的核算码名称
     * @return
     */
    List<String> queryAllHsmName();

    /**
     * 新增收费项目
     * @param zdChargeItem
     * @return
     */
    int saveZdChargeItem(ZdChargeItem zdChargeItem);

    /**
     * 修改收费项目
     *
     * @param zdChargeItem
     * @return
     */
    int modifyZdChargeItem(ZdChargeItem zdChargeItem);

    /**
     * 查询所有生效的收费项目字典列表
     *
     * @return
     */
    List<ZdChargeItem> queryAllInUsedZdCharge();
}
